<?php

namespace App\Http\Controllers;

use App\Admin;
use App\About;
use App\Video;
use App\Client;
use App\MainSlider;
use App\Showcase;
use App\Service;
use App\Staff;
use App\Subscribe;
use App\Title;
use Carbon\Carbon;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\File;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Input;
use Intervention\Image\Facades\Image;
use Illuminate\Support\Facades\Session;

class DashboardController extends Controller
{

    public function __construct()
    {
        $this->middleware('auth:admin');
    }
    public function getDashboard()
    {
        $data['page_title'] = "Dashboard";

        $data['totalService'] = Service::all()->count();
        $data['totalShowcase'] = Showcase::all()->count();
        $data['totalClient'] = Client::all()->count();
        $data['totalSubscriber'] = Subscribe::all()->count();

        return view('dashboard.dashboard',$data);
    }
    public function allSlider()
    {
        $data['page_title'] = "All Slide";
        $data['slides'] = MainSlider::orderBy('id','desc')->get();
        return view('dashboard.slider-all',$data);
    }
    public function createSlider()
    {
        $data['page_title'] = "Create New Slide";
        return view('dashboard.slider-create',$data);
    }
    public function submitSlider(Request $request)
    {
        $request->validate([
            'subtitle' => 'required',
            'title' => 'required',
            'description' => 'required',
            'link' => 'required',
        ]);
        $in = Input::except('_method','_token');       
        MainSlider::create($in);
        session()->flash('message', 'Slide Created Successfully.');
        Session::flash('type', 'success');
        Session::flash('title', 'Success');
        return redirect()->route('slider-all');
    }
    
    public function editSlider($id)
    {
        $data['page_title'] = "Edit Slide";
        $data['slider'] = MainSlider::findOrFail($id);
        return view('dashboard.slider-edit',$data);
    }

    public function updateSlider(Request $request,$id)
    {
        $slide = MainSlider::findOrFail($id);
        $request->validate([
            'subtitle' => 'required',
            'title' => 'required',
            'description' => 'required',
            'link' => 'required',
        ]);
        $in = Input::except('_method','_token');        
        $slide->fill($in)->save();
        session()->flash('message', 'Slider Update Successfully.');
        Session::flash('type', 'success');
        Session::flash('title', 'Success');
        return redirect()->route('slider-all');
    }
    public function deleteSlider(Request $request)
    {
        $request->validate([
            'id' => 'required'
        ]);
        $slide = MainSlider::findOrFail($request->id);       
        $slide->delete();
        session()->flash('message', 'Service Deleted Successfully.');
        Session::flash('type', 'success');
        Session::flash('title', 'Success');
        return redirect()->back();
    }

     public function EditAbout()
    {
        $data['page_title'] = "About";
        $data['about'] = About::first();
        return view('dashboard.about',$data);
    }   
    
    public function updateAbout(Request $request)
    {
        $about = About::first();
        $request->validate([
            'image' => 'mimes:png,jpeg,jpg',
            'description' => 'required',
            'link' => 'required',
        ]);
        $in = Input::except('_method','_token');
        if($request->hasFile('image')){
            $image = $request->file('image');
            $filename = 'about_'.time().'.'.$image->getClientOriginalExtension();
            $location = 'assets/images/' . $filename;
            Image::make($image)->resize(580,503)->save($location);
            $path = './assets/images/';
            $link = $path.$about->image;
            if (file_exists($link)) {
                unlink($link);
            }
            $in['image'] = $filename;
        }
        $about->fill($in)->save();
        session()->flash('message', 'About Update Successfully.');
        Session::flash('type', 'success');
        Session::flash('title', 'Success');
        return redirect()->route('about-edit');
    }
      public function EditVideo()
    {
        $data['page_title'] = "Video";
        $data['video'] = Video::first();
        return view('dashboard.video',$data);
    }
    public function updateVideo(Request $request)
    {
        $video = Video::first();
        $request->validate([
            'title' => 'required',
            'link' => 'required',
            'image' => 'mimes:png,jpeg,jpg',
        ]);
        $in = Input::except('_method','_token');
        if($request->hasFile('image')){
            $image = $request->file('image');
            $filename = 'video_'.time().'.'.$image->getClientOriginalExtension();
            $location = 'assets/images/' . $filename;
            Image::make($image)->resize(1600,900)->save($location);
            $path = './assets/images/';
            $link = $path.$video->image;
            if (file_exists($link)) {
                unlink($link);
            }
            $in['image'] = $filename;
        }
        $video->fill($in)->save();
        session()->flash('message', 'Video Update Successfully.');
        Session::flash('type', 'success');
        Session::flash('title', 'Success');
        return redirect()->route('video-edit');
    }
    public function mangeSubscribe()
    {
        $data['page_title'] = "All Subscribe";
        $data['subscribe'] = Subscribe::orderBy('id','desc')->get();
        return view('dashboard.subscribe',$data);
    }

    public function deleteSubscribe(Request $request)
    {
        $request->validate([
         'id' => 'required'
     ]);
        Subscribe::destroy($request->id);
        session()->flash('message','Subscriber Delete Successfully.');
        session()->flash('type','success');
        return redirect()->back();
    }
    public function allService()
    {
        $data['page_title'] = "All Service";
        $data['services'] = Service::orderBy('id','desc')->get();
        return view('dashboard.service-all',$data);
    }
    public function createService()
    {
        $data['page_title'] = "Create New Service";
        return view('dashboard.service-create',$data);
    }
    public function submitService(Request $request)
    {
        $request->validate([
            'name' => 'required',
            'image' => 'required|mimes:png,jpeg,jpg',
            'description' => 'required',
        ]);
        $in = Input::except('_method','_token');
        if($request->hasFile('image')){
            $image = $request->file('image');
            $filename = 'service_'.time().'.'.$image->getClientOriginalExtension();
            $location = 'assets/images/services/' . $filename;
            Image::make($image)->resize(370,263)->save($location);
            $in['image'] = $filename;
        }
        Service::create($in);
        session()->flash('message', 'Service Created Successfully.');
        Session::flash('type', 'success');
        Session::flash('title', 'Success');
        return redirect()->route('service-all');
    }
    
    public function editService($id)
    {
        $data['page_title'] = "Edit Service";
        $data['service'] = Service::findOrFail($id);
        return view('dashboard.service-edit',$data);
    }

    public function updateService(Request $request,$id)
    {
        $service = Service::findOrFail($id);
        $request->validate([
            'name' => 'required',
            'image' => 'mimes:png,jpeg,jpg',
            'description' => 'required',
        ]);
        $in = Input::except('_method','_token');
        if($request->hasFile('image')){
            $image = $request->file('image');
            $filename = 'service_'.time().'.'.$image->getClientOriginalExtension();
            $location = 'assets/images/services/' . $filename;
            Image::make($image)->resize(370,263)->save($location);
            $path = './assets/images/services/';
            $link = $path.$service->image;
            if (file_exists($link)) {
                unlink($link);
            }
            $in['image'] = $filename;
        }
        $service->fill($in)->save();
        session()->flash('message', 'Service Update Successfully.');
        Session::flash('type', 'success');
        Session::flash('title', 'Success');
        return redirect()->route('service-all');
    }
    public function deleteService(Request $request)
    {
        $request->validate([
            'id' => 'required'
        ]);
        $service = Service::findOrFail($request->id);
        $path = './assets/images/services/';
        $link = $path.$service->image;
        if (file_exists($link)) {
            unlink($link);
        }
        $service->delete();
        session()->flash('message', 'Service Deleted Successfully.');
        Session::flash('type', 'success');
        Session::flash('title', 'Success');
        return redirect()->back();
    }

       public function allShowcase()
    {
        $data['page_title'] = "All Showcase";
        $data['showcases'] = Showcase::orderBy('id','desc')->get();
        return view('dashboard.showcase-all',$data);
    }
    public function createShowcase()
    {
        $data['page_title'] = "Create New Showcase";
        return view('dashboard.showcase-create',$data);
    }
    public function submitShowcase(Request $request)
    {
        $request->validate([
            'thumbnail' => 'required|mimes:jpeg,jpg',
            'image' => 'required|mimes:jpeg,jpg',
        ]);
        $in = Input::except('_method','_token','thumbnail');
        if($request->hasFile('thumbnail')){
            $image = $request->file('thumbnail');
            $filename = 'showcase_'.time().'.'.$image->getClientOriginalExtension();
            $location = 'assets/images/showcases/small/' . $filename;
            Image::make($image)->resize(250,250)->save($location);
        }   
        if($request->hasFile('image')){
            $image = $request->file('image');
            $filename = 'showcase_'.time().'.'.$image->getClientOriginalExtension();
            $location_large = 'assets/images/showcases/large/' . $filename;
            Image::make($image)->save($location_large);
            $in['image'] = $filename;
        }
        Showcase::create($in);
        session()->flash('message', 'Showcase Created Successfully.');
        Session::flash('type', 'success');
        Session::flash('title', 'Success');
        return redirect()->route('showcase-all');
    }
    
    public function editShowcase($id)
    {
        $data['page_title'] = "Edit Showcase";
        $data['showcase'] = Showcase::findOrFail($id);
        return view('dashboard.showcase-edit',$data);
    }

     public function updateShowcase(Request $request,$id)
    {
        $showcase = Showcase::findOrFail($id);
        $request->validate([
            'thumbnail' => 'required|mimes:jpeg,jpg',
            'image' => 'required|mimes:jpeg,jpg',
        ]);
        $in = Input::except('_method','_token','thumbnail');
        if($request->hasFile('thumbnail')){
            $image = $request->file('thumbnail');
            $filename = 'showcase_'.time().'.'.$image->getClientOriginalExtension();
            $location = 'assets/images/showcases/small/' . $filename;
            Image::make($image)->resize(250,250)->save($location);
        }   
        if($request->hasFile('image')){
            $image = $request->file('image');
            $filename = 'showcase_'.time().'.'.$image->getClientOriginalExtension();
            $location_large = 'assets/images/showcases/large/' . $filename;
            Image::make($image)->save($location_large);
            $in['image'] = $filename;
        }
        $showcase->fill($in)->save();
        session()->flash('message', 'Showcase Update Successfully.');
        Session::flash('type', 'success');
        Session::flash('title', 'Success');
        return redirect()->route('showcase-all');
    }
    public function deleteShowcase(Request $request)
    {
        $request->validate([
            'id' => 'required'
        ]);
        $showcase = Showcase::findOrFail($request->id);
        $large = './assets/images/showcases/large/';
        $small = './assets/images/showcases/small/';
        $largeLink = $large.$showcase->image;
        $smallLink = $small.$showcase->image;
        if (file_exists($largeLink)) {
            unlink($largeLink);
        }  
        if (file_exists($smallLink)) {
            unlink($smallLink);
        }
        $showcase->delete();
        session()->flash('message', 'Showcase Deleted Successfully.');
        Session::flash('type', 'success');
        Session::flash('title', 'Success');
        return redirect()->back();
    }

     public function allClient()
    {
        $data['page_title'] = "All Client";
        $data['clients'] = Client::orderBy('id','desc')->get();
        return view('dashboard.client-all',$data);
    }
    public function createClient()
    {
        $data['page_title'] = "Create New Client";
        return view('dashboard.client-create',$data);
    }
    public function submitClient(Request $request)
    {
        $request->validate([
            'name' => 'required',
            'image' => 'required|mimes:png,jpeg,jpg',
            'address' => 'required',
        ]);
        $in = Input::except('_method','_token');
        if($request->hasFile('image')){
            $image = $request->file('image');
            $filename = 'client_'.time().'.'.$image->getClientOriginalExtension();
            $location = 'assets/images/clients/' . $filename;
            Image::make($image)->resize(370,263)->save($location);
            $in['image'] = $filename;
        }
        Client::create($in);
        session()->flash('message', 'Client Created Successfully.');
        Session::flash('type', 'success');
        Session::flash('title', 'Success');
        return redirect()->route('client-all');
    }
    
    public function editClient($id)
    {
        $data['page_title'] = "Edit Client";
        $data['client'] = Client::findOrFail($id);
        return view('dashboard.client-edit',$data);
    }

    public function updateClient(Request $request,$id)
    {
        $client = Client::findOrFail($id);
        $request->validate([
            'name' => 'required',
            'image' => 'mimes:png,jpeg,jpg',
            'address' => 'required',
        ]);
        $in = Input::except('_method','_token');
        if($request->hasFile('image')){
            $image = $request->file('image');
            $filename = 'client_'.time().'.'.$image->getClientOriginalExtension();
            $location = 'assets/images/clients/' . $filename;
            Image::make($image)->resize(370,263)->save($location);
            $path = './assets/images/clients/';
            $link = $path.$client->image;
            if (file_exists($link)) {
                unlink($link);
            }
            $in['image'] = $filename;
        }
        $client->fill($in)->save();
        session()->flash('message', 'Client Update Successfully.');
        Session::flash('type', 'success');
        Session::flash('title', 'Success');
        return redirect()->route('client-all');
    }
    public function deleteClient(Request $request)
    {
        $request->validate([
            'id' => 'required'
        ]);
        $client = Client::findOrFail($request->id);
        $path = './assets/images/clients/';
        $link = $path.$client->image;
        if (file_exists($link)) {
            unlink($link);
        }
        $client->delete();
        session()->flash('message', 'Client Deleted Successfully.');
        Session::flash('type', 'success');
        Session::flash('title', 'Success');
        return redirect()->back();
    }
      public function manageStaff()
    {
        $data['page_title'] = 'Manage Staff';
        $data['staff'] = Staff::all();
        return view('dashboard.staff',$data);
    }
      public function createStaff()
    {
        $data['page_title'] = 'Create Staff';
        return view('dashboard.staff-create',$data);
    }
    public function storeStaff(Request $request)
    {
        $request->validate([
            'email' => 'required|unique:staff',
            'name' => 'required',
            'password' => 'required|confirmed|min:5'
        ]);
        $in = Input::except('_method','_token');
        $in['password'] = bcrypt($request->password);
        Staff::create($in);

        session()->flash('message', 'Staff added Successfully.');
        Session::flash('type', 'success');
        Session::flash('title', 'Success');
        return redirect()->route('manage-staff');

    }
    public function editStaff($product_id)
    {
        $data['page_title'] = 'Edit Staff';
         $data['staff'] = Staff::find($product_id);
        return view('dashboard.staff-edit',$data);
    }
    public function updateStaff(Request $request,$product_id)
    {
        $product = Staff::find($product_id);
        $request->validate([
            'email' => 'required|unique:staff,email,'.$product->id,
            'name' => 'required',
            'password' => 'nullable|confirmed|min:5'
        ]);
        $product->name = $request->name;
        $product->email = $request->email;
        if ($request->password != null){
            $product->password = bcrypt($request->password);
        }
        $product->save();
        session()->flash('message', 'Staff Updated Successfully.');
        Session::flash('type', 'success');
        Session::flash('title', 'Success');
        return redirect()->route('manage-staff');
    }
     public function deleteStaff(Request $request)
    {
        $request->validate([
            'id' => 'required'
        ]);
        $staff = Staff::findOrFail($request->id);
       
        $staff->delete();
        session()->flash('message', 'Staff Deleted Successfully.');
        Session::flash('type', 'success');
        Session::flash('title', 'Success');
        return redirect()->back();
    }
    
}
