<?php

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/


if(version_compare(PHP_VERSION, '7.2.0', '>=')) {
    error_reporting(E_ALL ^ E_NOTICE ^ E_WARNING);
} 

Route::get('/',['as'=>'home','uses'=>'HomeController@getIndex']);
Route::get('about',['as'=>'about','uses'=>'HomeController@getAbout']);
Route::get('showcase',['as'=>'showcase','uses'=>'HomeController@getShowcase']);

Route::get('cron-fire',['as'=>'cron-fire','uses'=>'HomeController@submitCronJob']);
Route::post('submit-subscribe',['as'=>'submit-subscribe','uses'=>'HomeController@submitSubscribe']);


/*---------------- Admin Auth Route List --------------------*/

Route::get('mojho', 'Admin\LoginController@showLoginForm')->name('admin.login');
Route::post('mojho', 'Admin\LoginController@login')->name('admin.login.post');
Route::get('mojho/password/reset', 'Admin\ForgotPasswordController@showLinkRequestForm')->name('admin.password.request');
Route::post('mojho/password/email', 'Admin\ForgotPasswordController@sendResetLinkEmail')->name('admin.password.email');
Route::get('mojho/password/reset/{token}', 'Admin\ResetPasswordController@showResetForm')->name('admin.password.reset');
Route::post('mojho/password/reset', 'Admin\ResetPasswordController@reset');
Route::get('admin-logout', 'Admin\LoginController@logout')->name('admin.logout');



/*===================== Admin Dashboard Redirected ====================*/

Route::get('admin-dashboard',['as'=>'dashboard','uses'=>'DashboardController@getDashboard']);

Route::group(['prefix' => 'mojho'], function () {

    Route::get('edit-profile',['as'=>'edit-profile','uses'=>'BasicSettingController@editProfile']);
    Route::post('edit-profile',['as'=>'update-profile','uses'=>'BasicSettingController@updateProfile']);

    Route::get('change-password', ['as'=>'admin-change-password', 'uses'=>'BasicSettingController@getChangePass']);
    Route::post('change-password', ['as'=>'admin-change-password', 'uses'=>'BasicSettingController@postChangePass']);

    Route::get('basic-setting', ['as' => 'basic-setting', 'uses' => 'BasicSettingController@getBasicSetting']);
    Route::put('basic-general/{id}', ['as' => 'basic-update', 'uses' => 'BasicSettingController@putBasicSetting']);

    Route::get('manage-logo', ['as' => 'manage-logo', 'uses' => 'WebSettingController@manageLogo']);
    Route::post('manage-logo', ['as' => 'manage-logo', 'uses' => 'WebSettingController@updateLogo']);

    Route::get('manage-footer', ['as' => 'manage-footer', 'uses' => 'WebSettingController@manageFooter']);
    Route::put('manage-footer/{id}', ['as' => 'manage-footer-update', 'uses' => 'WebSettingController@updateFooter']);


    Route::get('google-analytic',['as'=>'google-analytic','uses'=>'BasicSettingController@getGoogleAnalytic']);
    Route::post('google-analytic',['as'=>'google-analytic','uses'=>'BasicSettingController@updateGoogleAnalytic']);


    Route::get('cron-job',['as'=>'cron-job','uses'=>'BasicSettingController@setCronJob']);


    Route::get('manage-social',['as'=>'manage-social','uses'=>'WebSettingController@manageSocial']);
    Route::post('manage-social',['as'=>'manage-social','uses'=>'WebSettingController@storeSocial']);
    Route::get('manage-social/{product_id?}',['as'=>'social-edit','uses'=>'WebSettingController@editSocial']);
    Route::put('manage-social/{product_id?}',['as'=>'social-edit','uses'=>'WebSettingController@updateSocial']);
    Route::delete('manage-social/{product_id?}',['as'=>'social-delete','uses'=>'WebSettingController@deleteSocial']);



    Route::get('about-edit',['as'=>'about-edit','uses'=>'DashboardController@EditAbout']);
    Route::put('about-edit',['as'=>'about-update','uses'=>'DashboardController@updateAbout']);

    Route::get('video-edit',['as'=>'video-edit','uses'=>'DashboardController@EditVideo']);
    Route::put('video-edit',['as'=>'video-update','uses'=>'DashboardController@updateVideo']);



    Route::get('about-title-edit',['as'=>'about-title-edit','uses'=>'WebSettingController@EditAboutTitle']);
    Route::put('about-title-edit',['as'=>'about-title-edit','uses'=>'WebSettingController@updateAboutTitle']);
    Route::get('service-title-edit',['as'=>'service-title-edit','uses'=>'WebSettingController@EditServiceTitle']);
    Route::put('service-title-edit',['as'=>'service-title-edit','uses'=>'WebSettingController@updateServiceTitle']);    
    Route::get('showcase-title-edit',['as'=>'showcase-title-edit','uses'=>'WebSettingController@EditShowcaseTitle']);
    Route::put('showcase-title-edit',['as'=>'showcase-title-edit','uses'=>'WebSettingController@updateShowcaseTitle']);
    Route::get('recent-title-edit',['as'=>'recent-title-edit','uses'=>'WebSettingController@EditRecentTitle']);
    Route::put('recent-title-edit',['as'=>'recent-title-edit','uses'=>'WebSettingController@updateRecentTitle']);
    Route::get('client-title-edit',['as'=>'client-title-edit','uses'=>'WebSettingController@EditClientTitle']);
    Route::put('client-title-edit',['as'=>'client-title-edit','uses'=>'WebSettingController@updateClientTitle']);



    Route::get('slider-create',['as'=>'slider-create','uses'=>'DashboardController@createSlider']);
    Route::post('slider-create',['as'=>'slider-create','uses'=>'DashboardController@submitSlider']);
    Route::get('slider-all',['as'=>'slider-all','uses'=>'DashboardController@allSlider']);
    Route::get('slider-edit/{id}',['as'=>'slider-edit','uses'=>'DashboardController@editSlider']);
    Route::put('slider-edit/{id}',['as'=>'slider-update','uses'=>'DashboardController@updateSlider']);
    Route::delete('slider-delete',['as'=>'slider-delete','uses'=>'DashboardController@deleteSlider']);



    Route::get('service-create',['as'=>'service-create','uses'=>'DashboardController@createService']);
    Route::post('service-create',['as'=>'service-create','uses'=>'DashboardController@submitService']);
    Route::get('service-all',['as'=>'service-all','uses'=>'DashboardController@allService']);
    Route::get('service-edit/{id}',['as'=>'service-edit','uses'=>'DashboardController@editService']);
    Route::put('service-edit/{id}',['as'=>'service-update','uses'=>'DashboardController@updateService']);
    Route::delete('service-delete',['as'=>'service-delete','uses'=>'DashboardController@deleteService']);

    Route::get('showcase-create',['as'=>'showcase-create','uses'=>'DashboardController@createShowcase']);
    Route::post('showcase-create',['as'=>'showcase-create','uses'=>'DashboardController@submitShowcase']);
    Route::get('showcase-all',['as'=>'showcase-all','uses'=>'DashboardController@allShowcase']);
    Route::get('showcase-edit/{id}',['as'=>'showcase-edit','uses'=>'DashboardController@editShowcase']);
    Route::put('showcase-edit/{id}',['as'=>'showcase-update','uses'=>'DashboardController@updateShowcase']);
    Route::delete('showcase-delete',['as'=>'showcase-delete','uses'=>'DashboardController@deleteShowcase']);



    Route::get('client-create',['as'=>'client-create','uses'=>'DashboardController@createClient']);
    Route::post('client-create',['as'=>'client-create','uses'=>'DashboardController@submitClient']);
    Route::get('client-all',['as'=>'client-all','uses'=>'DashboardController@allClient']);
    Route::get('client-edit/{id}',['as'=>'client-edit','uses'=>'DashboardController@editClient']);
    Route::put('client-edit/{id}',['as'=>'client-update','uses'=>'DashboardController@updateClient']);
    Route::delete('client-delete',['as'=>'client-delete','uses'=>'DashboardController@deleteClient']);

    Route::get('manage-subscribe',['as'=>'manage-subscribe','uses'=>'DashboardController@mangeSubscribe']);
    Route::delete('subscriber-delete',['as'=>'subscriber-delete','uses'=>'DashboardController@deleteSubscribe']);

    Route::get('manage-staff',['as'=>'manage-staff','uses'=>'DashboardController@manageStaff']);
    Route::get('staff-create',['as'=>'staff-create','uses'=>'DashboardController@createStaff']);
    Route::post('staff-create',['as'=>'staff-create','uses'=>'DashboardController@storeStaff']);
    Route::get('staff-edit/{product_id?}',['as'=>'staff-edit','uses'=>'DashboardController@editStaff']);
    Route::put('staff-edit/{product_id?}',['as'=>'staff-edit','uses'=>'DashboardController@updateStaff']);    
    Route::delete('staff-delete',['as'=>'staff-delete','uses'=>'DashboardController@deleteStaff']);

});

/*---------------- Staff Auth Route List --------------------*/

Route::get('staff', 'Staff\LoginController@showLoginForm')->name('staff.login');
Route::post('staff', 'Staff\LoginController@login')->name('staff.login.post');
Route::get('staff/password/reset', 'Staff\ForgotPasswordController@showLinkRequestForm')->name('staff.password.request');
Route::post('staff/password/email', 'Staff\ForgotPasswordController@sendResetLinkEmail')->name('staff.password.email');
Route::get('staff/password/reset/{token}', 'Staff\ResetPasswordController@showResetForm')->name('staff.password.reset');
Route::post('staff/password/reset', 'Staff\ResetPasswordController@reset');
Route::get('staff-logout', 'Staff\LoginController@logout')->name('staff.logout');

Route::get('staff-dashboard',['as'=>'staff-dashboard','uses'=>'StaffController@getDashboard']);

Route::group(['prefix' => 'staff'], function () {

    Route::get('edit-profile',['as'=>'staff-edit-profile','uses'=>'StaffController@editProfile']);
    Route::post('edit-profile',['as'=>'staff-update-profile','uses'=>'StaffController@updateProfile']);

    Route::get('change-password', ['as'=>'staff-change-password', 'uses'=>'StaffController@getChangePass']);
    Route::post('change-password', ['as'=>'staff-change-password', 'uses'=>'StaffController@postChangePass']);


    Route::get('about-edit',['as'=>'staff-about-edit','uses'=>'StaffController@EditAbout']);
    Route::put('about-edit',['as'=>'staff-about-update','uses'=>'StaffController@updateAbout']);

    Route::get('video-edit',['as'=>'staff-video-edit','uses'=>'StaffController@EditVideo']);
    Route::put('video-edit',['as'=>'staff-video-update','uses'=>'StaffController@updateVideo']);

    Route::get('slider-create',['as'=>'staff-slider-create','uses'=>'StaffController@createSlider']);
    Route::post('slider-create',['as'=>'staff-slider-create','uses'=>'StaffController@submitSlider']);
    Route::get('slider-all',['as'=>'staff-slider-all','uses'=>'StaffController@allSlider']);
    Route::get('slider-edit/{id}',['as'=>'staff-slider-edit','uses'=>'StaffController@editSlider']);
    Route::put('slider-edit/{id}',['as'=>'staff-slider-update','uses'=>'StaffController@updateSlider']);
    Route::delete('slider-delete',['as'=>'staff-slider-delete','uses'=>'StaffController@deleteSlider']);



    Route::get('service-create',['as'=>'staff-service-create','uses'=>'StaffController@createService']);
    Route::post('service-create',['as'=>'staff-service-create','uses'=>'StaffController@submitService']);
    Route::get('service-all',['as'=>'staff-service-all','uses'=>'StaffController@allService']);
    Route::get('service-edit/{id}',['as'=>'staff-service-edit','uses'=>'StaffController@editService']);
    Route::put('service-edit/{id}',['as'=>'staff-service-update','uses'=>'StaffController@updateService']);
    Route::delete('service-delete',['as'=>'staff-service-delete','uses'=>'StaffController@deleteService']);

    Route::get('showcase-create',['as'=>'staff-showcase-create','uses'=>'StaffController@createShowcase']);
    Route::post('showcase-create',['as'=>'staff-showcase-create','uses'=>'StaffController@submitShowcase']);
    Route::get('showcase-all',['as'=>'staff-showcase-all','uses'=>'StaffController@allShowcase']);
    Route::get('showcase-edit/{id}',['as'=>'staff-showcase-edit','uses'=>'StaffController@editShowcase']);
    Route::put('showcase-edit/{id}',['as'=>'staff-showcase-update','uses'=>'StaffController@updateShowcase']);
    Route::delete('showcase-delete',['as'=>'staff-showcase-delete','uses'=>'StaffController@deleteShowcase']);

    

    Route::get('client-create',['as'=>'staff-client-create','uses'=>'StaffController@createClient']);
    Route::post('client-create',['as'=>'staff-client-create','uses'=>'StaffController@submitClient']);
    Route::get('client-all',['as'=>'staff-client-all','uses'=>'StaffController@allClient']);
    Route::get('client-edit/{id}',['as'=>'staff-client-edit','uses'=>'StaffController@editClient']);
    Route::put('client-edit/{id}',['as'=>'staff-client-update','uses'=>'StaffController@updateClient']);
    Route::delete('client-delete',['as'=>'staff-client-delete','uses'=>'StaffController@deleteClient']);


    Route::get('manage-subscribe',['as'=>'staff-manage-subscribe','uses'=>'StaffController@mangeSubscribe']);
    Route::delete('subscriber-delete',['as'=>'staff-subscriber-delete','uses'=>'StaffController@deleteSubscribe']);

});
